@@ -1,6 +1,8 @@
 """
 Feature overview
 ================
+This paragraph is from __init__.py
+
 With kmcos you can:
 
     * easily create and modify kMC models through GUI
@@ -16,13 +18,15 @@ kmcos' goal is to significantly reduce the time you need
 to implement and run a lattice kmc simulation. However it can not help
 you plan the model.
 
+Typical users will run kmcos entirely from python code by following the examples.
 
-kmcos can be invoked directly from the command line in one of the following
+In technical terms, kmcos is run  an API via the kmcos python module.
+
+Additionally, though now discouraged, kmcos can be invoked directly from the command line in one of the following
 ways::
 
     kmcos [help] (all|benchmark|build|edit|export|help|import|rebuild|run|settings-export|shell|version|view|xml) [options]
 
-or it may be used as an API via the *kmcos* module.
 
 .. rubric:: Footnotes
 
@@ -51,7 +55,7 @@ from __future__ import print_function
 #import kmcos.types
 #import kmcos.io
 
-__version__ = "0.0.15"
+__version__ = "0.0.51"
 VERSION = __version__
 
 def evaluate_param_expression(param, parameters={}):
@@ -435,3 +439,46 @@ def evaluate_rate_expression(rate_expr, parameters={}):
                 % (rate_expr, e))
 
     return rate_const
+
+def compile(kmc_model):
+    import kmcos
+    kmcos.export(kmc_model.filename + ' -b' + kmc_model.backend)
+
+#kmcos can be invoked directly from the command line in one of the following ways::
+#    kmcos [help] (all|benchmark|build|edit|export|help|import|rebuild|run|settings-export|shell|version|view|xml) [options]
+#defining small wrapper functions to call cli if person types kmcos.export("MyFirstModel.xml") etc. Probably should have made an "@" decorator, but that's okay.
+def build(argumentsString):
+    import kmcos.cli as cli
+    cli.main('build' +' ' + argumentsString)
+def edit(argumentsString):
+    import kmcos.cli as cli
+    cli.main('edit'+' ' + argumentsString)
+def export(argumentsString):
+    import kmcos.cli as cli
+    cli.main('export'+' ' + argumentsString)
+def help(argumentsString):
+    import kmcos.cli as cli
+    cli.main('help' +' '+ argumentsString)
+def rebuild(argumentsString):
+    import kmcos.cli as cli
+    cli.main('rebuild'+' ' + argumentsString)
+def run(argumentsString):
+    import kmcos.cli as cli
+    cli.main('run'+' ' + argumentsString)
+def settings_export(argumentsString):
+    import kmcos.cli as cli
+    cli.main('settings-export'+' ' + argumentsString)
+def shell(argumentsString):
+    import kmcos.cli as cli
+    cli.main('shell'+' ' + argumentsString)    
+def version(argumentsString):
+    import kmcos.cli as cli
+    cli.main('version'+' ' + argumentsString)    
+def viewer(argumentsString): #TODO: should change the view.py file to viewer, and change this to view.
+    import kmcos.cli as cli
+    cli.main('view'+' ' + argumentsString)    
+def xml(argumentsString):
+    import kmcos.cli as cli
+    cli.main('xml'+' ' + argumentsString)    
+
+from kmcos.io import clear_model
