@@ -70,8 +70,12 @@ def GibbsAds(energy, frequencies, T):
     vib_energies=list(frequencies)
     for i in range(len(vib_energies)):
         vib_energies[i]=vib_energies[i]*cm_to_eV
-    thermo_ads=HarmonicThermo(vib_energies=vib_energies, electronicenergy=energy)
-    val=thermo_ads.get_gibbs_energy(temperature=T,verbose=False)
+    thermo_ads=HarmonicThermo(vib_energies=vib_energies, potentialenergy=energy)
+    #In older versions of ASE the Helmholtz energy was called the Gibbs free energy.
+    #However, nothing has changed in what is actually calculated.
+    #The two different free energies are approximately equal since their difference (the pV term) is small.
+    #This pV term was always neglected.
+    val=thermo_ads.get_helmholtz_energy(temperature=T,verbose=False)
     return val
 
 class Species(object):
@@ -95,7 +99,7 @@ class Species(object):
         if self.gas and self.janaf_file and janaf_data is not None:
             self._prepare_G_p0(
                 os.path.abspath(os.path.join(
-                janaf_data.__path__[0],
+                list(janaf_data.__path__)[0],
                 self.janaf_file)))
 
     def __repr__(self):
@@ -127,7 +131,7 @@ class Species(object):
             for i in range(len(vib_energies)):
                 vib_energies[i]=vib_energies[i]*cm_to_eV
             thermo_gas=IdealGasThermo(vib_energies=vib_energies,
-                            electronicenergy=energy,
+                            potentialenergy=energy,
                             atoms=self.atoms,
                             geometry=self.geometry,
                             symmetrynumber=self.symmetrynumber,
