@@ -81,14 +81,20 @@ class Project(object):
         - Processes
     """
 
-    def __init__(self):
+    def __init__(self, model_name=None):
         self.meta = Meta()
+        if type(model_name)==type(None):
+            self.model_name = "UntitledModel"
+        else:
+            self.model_name = model_name 
         self.layer_list = LayerList()
         self.lattice = self.layer_list
         self.parameter_list = ParameterList()
         self.species_list = SpeciesList()
         self.process_list = ProcessList()
         self.output_list = OutputList()
+        self.filename = self.model_name + ".xml"
+        self.backend = "local_smart" #this is just the default.
 
         # Quick'n'dirty define access functions
         # needed in context with GTKProject
@@ -559,6 +565,11 @@ class Project(object):
         with open('abbreviations_{}.dat'.format(self.meta.model_name), 'w') as outfile:
             outfile.write(pprint.pformat(stub_map))
 
+    def clear_model(self, model_name, backend=''):
+        if backend=='': backend = self.backend
+        import kmcos.io
+        kmcos.io.clear_model(model_name, backend=backend)
+    
     def save(self, filename=None, validate=True):
         if filename is None:
             filename = self.filename
@@ -570,6 +581,7 @@ class Project(object):
         else:
             raise UserWarning('Cannot export to file suffix %s' %
                               os.path.splitext(filename)[-1])
+    save_model = save
 
     def export_xml_file(self, filename, validate=True):
         f = open(filename, 'w')
@@ -1300,16 +1312,24 @@ class Project(object):
                  model_name=None,
                  model_dimension=None,
                  debug=None):
-        if author is not None:
-            self.meta.author = author
-        if email is not None:
-            self.meta.email = email
-        if model_name is not None:
-            self.meta.model_name = model_name
-        if model_dimension is not None:
-            self.meta.model_dimension = model_dimension
-        if debug is not None:
-            self.meta.debug = debug
+        if type(author) != type(None):
+            self.meta.author = str(author)
+        if type(email) != type(None):
+            self.meta.email = str(email)
+        if type(model_name) != type(None):
+            self.meta.model_name = str(model_name)
+        if type(model_dimension) != type(None):
+            self.meta.model_dimension = int(model_dimension)
+        if type(debug) != type(None):
+            self.meta.debug = str(debug)
+
+
+def create_kmc_model(model_name=None):
+    if type(model_name) == type(None):
+        pt = Project()
+    else:
+        pt = Project(model_name)
+    return pt
 
 
 class Meta(object):
@@ -1923,7 +1943,8 @@ class Process(FixedObject):
         self.bystander_list = kwargs.get('bystander_list', [])
         self.tof_count = kwargs.get('tof_count', None)
         self.enabled = kwargs.get('enabled', True)
-
+    
+    #TODO: Change "Rate" below to Transition_Frequency if doing so does not break anything.
     def __repr__(self):
         repr_str = ('[PROCESS] Name:%s\n'
                     '     Rate: %s\n'
